@@ -476,6 +476,48 @@ To: ant@example.com
         with get_dns_resolver(rdata=b'v=DMARC1; pct=100;'):
             self.assertFalse(rule.check(mlist, msg, {}))
 
+    def test_address_in_dmarc_addresses(self):
+        mlist = create_list('ant@example.com')
+        # Use action reject.  The rule only hits on reject and discard.
+        mlist.dmarc_mitigate_action = DMARCMitigateAction.reject
+        mlist.dmarc_addresses = ['anne@example.biz']
+        msg = mfs("""\
+From: anne@example.biz
+To: ant@example.com
+
+""")
+        rule = dmarc.DMARCMitigation()
+        with get_dns_resolver(rdata=b'v=DMARC1; p=none;'):
+            self.assertTrue(rule.check(mlist, msg, {}))
+
+    def test_address_in_dmarc_addresses_regex(self):
+        mlist = create_list('ant@example.com')
+        # Use action reject.  The rule only hits on reject and discard.
+        mlist.dmarc_mitigate_action = DMARCMitigateAction.reject
+        mlist.dmarc_addresses = ['^.*@example.biz']
+        msg = mfs("""\
+From: anne@example.biz
+To: ant@example.com
+
+""")
+        rule = dmarc.DMARCMitigation()
+        with get_dns_resolver(rdata=b'v=DMARC1; p=none;'):
+            self.assertTrue(rule.check(mlist, msg, {}))
+
+    def test_address_in_dmarc_addresses_no_hit(self):
+        mlist = create_list('ant@example.com')
+        # Use action reject.  The rule only hits on reject and discard.
+        mlist.dmarc_mitigate_action = DMARCMitigateAction.reject
+        mlist.dmarc_addresses = ['anne@example.com']
+        msg = mfs("""\
+From: anne@example.biz
+To: ant@example.com
+
+""")
+        rule = dmarc.DMARCMitigation()
+        with get_dns_resolver(rdata=b'v=DMARC1; p=none;'):
+            self.assertFalse(rule.check(mlist, msg, {}))
+
     def test_parser(self):
         data_file = str(self.resources.enter_context(
             path('mailman.rules.tests.data', 'org_domain.txt')))
@@ -513,6 +555,8 @@ class TestableHandler(BaseHTTPRequestHandler):
             self.send_header('Content-Type', 'UTF-8')
             self.end_headers()
             self.wfile.write(b'abc')
+        elif self.path == '/internal-server-error':
+            self.send_error(HTTPStatus.INTERNAL_SERVER_ERROR)
         else:
             self.send_error(HTTPStatus.NOT_FOUND)
 
@@ -591,9 +635,9 @@ class TestSuffixList(TestCase):
 
     @configuration(
         'dmarc',
-        org_domain_data_url='http://localhost:8180/public_suffix_list.err')
-    def test_cached_copy_is_missing_download_404s(self):
-        # There's no cached file and we'll get a 404 with the .err file so
+        org_domain_data_url='http://localhost:8180/not-found')
+    def test_cached_copy_is_missing_download_not_found(self):
+        # There's no cached file and we'll get a 404 (Not Found) so
         # we'll have to fall back to our internal copy.
         cache_path = os.path.join(config.VAR_DIR, dmarc.LOCAL_FILE_NAME)
         self.assertFalse(os.path.exists(cache_path))
@@ -611,8 +655,8 @@ class TestSuffixList(TestCase):
 
     @configuration(
         'dmarc',
-        org_domain_data_url='http://localhost:8180/public_suffix_list.err')
-    def test_cached_copy_is_expired_download_404s(self):
+        org_domain_data_url='http://localhost:8180/not-found')
+    def test_cached_copy_is_expired_download_not_found(self):
         # Because the cached copy is out of date, we try to download the new
         # version.  But that 404s so we end up continuing to use the cached
         # copy.
@@ -631,3 +675,13 @@ class TestSuffixList(TestCase):
         self.assertEqual(contents, 'xyz')
         # The cached file timestamp doesn't change.
         self.assertEqual(os.stat(new_path).st_mtime, expires)
+
+    @configuration(
+        'dmarc',
+        org_domain_data_url='http://localhost:8180/internal-server-error')
+    def test_download_internal_server_error(self):
+        # https://gitlab.com/mailman/mailman/-/issues/1140
+        cache_path = os.path.join(config.VAR_DIR, dmarc.LOCAL_FILE_NAME)
+        self.assertFalse(os.path.exists(cache_path))
+        new_path = dmarc.ensure_current_suffix_list()
+        self.assertEqual(cache_path, new_path)
