@@ -250,11 +250,7 @@ class Moderation:
         mlist.max_message_size = 40               # KB
         mlist.require_explicit_destination = True
         mlist.bounce_matching_headers = """
-# Lines that *start* with a '#' are comments.
-to: friend@public.com
-message-id: relay.comanche.denmark.eu
-from: list@listme.com
-from: .*@uplinkpro.com
+# This is a deprecated setting from Mailman 2.1. Use header_matches instead.
 """
         mlist.header_matches = []
         mlist.administrivia = True
