@@ -106,6 +106,17 @@ class TestBasicImport(unittest.TestCase):
         self.assertTrue(self._mlist.allow_list_posts)
         self.assertTrue(self._mlist.include_rfc2369_headers)
 
+    def test_subject_prefix_spaces(self):
+        self._pckdict['subject_prefix'] = '  '
+        self._import()
+        self.assertEqual(self._mlist.subject_prefix, '')
+        self._pckdict['subject_prefix'] = '[prefix]'
+        self._import()
+        self.assertEqual(self._mlist.subject_prefix, '[prefix] ')
+        self._pckdict['subject_prefix'] = '  [prefix]  '
+        self._import()
+        self.assertEqual(self._mlist.subject_prefix, '[prefix] ')
+
     def test_no_overwrite_rosters(self):
         # The mlist.members and mlist.digest_members rosters must not be
         # overwritten.
@@ -330,6 +341,15 @@ class TestBasicImport(unittest.TestCase):
         self.assertEqual('This is text.\n',
                          self._mlist.dmarc_wrapped_message_text)
 
+    def test_dmarc_addresses(self):
+        self._pckdict['dmarc_moderation_addresses'] = [
+            b'user@example.com',
+            b'^.*@gmail.com',
+            ]
+        self._import()
+        self.assertEqual(['user@example.com', '^.*@gmail.com'],
+                         self._mlist.dmarc_addresses)
+
     def test_ban_list(self):
         banned = [
             ('anne@example.net', 'anne@example.net'),
@@ -341,6 +361,26 @@ class TestBasicImport(unittest.TestCase):
         for _pattern, addr in banned:
             self.assertTrue(IBanManager(self._mlist).is_banned(addr))
 
+    def test_ban_list_invalid_regex(self):
+        expected = """\
+Dropping invalid regexp ^**@example.edu in ban_list
+nothing to repeat at position 1"""
+        banned = [
+            ('^**@example.edu', 'bob@example.edu'),
+            ('anne@example.net', 'anne@example.net'),
+            ('^.*@example.net', 'bob@example.net'),
+            ]
+        self._pckdict['ban_list'] = [b[0].encode('iso-8859-1') for b in banned]
+        serr = StringIO()
+        with redirect_stderr(serr):
+            self._import()
+        self.assertIn(expected, serr.getvalue())
+        serr.close()
+        for _pattern, addr in banned[1:]:
+            self.assertTrue(IBanManager(self._mlist).is_banned(addr))
+        self.assertEqual([x.email for x in IBanManager(self._mlist).bans],
+                         ['^.*@example.net', 'anne@example.net'])
+
     def test_acceptable_aliases(self):
         # This used to be a plain-text field (values are newline-separated)
         # but values were interpreted as regexps even without '^' so we need
@@ -1101,6 +1141,7 @@ class TestRosterImport(unittest.TestCase):
             'accept_these_nonmembers': [
                 'gene@example.com',
                 '^gene-.*@example.com',
+                '@list',
                 ],
             'hold_these_nonmembers': [
                 'homer@example.com',
@@ -1337,8 +1378,15 @@ class TestRosterImport(unittest.TestCase):
             list_prop = getattr(
                 self._mlist,
                 '{}_these_nonmembers'.format(action.name))
-            self.assertEqual(len(list_prop), 1)
-            self.assertTrue(all(addr.startswith('^') for addr in list_prop))
+            if action == Action.accept:
+                self.assertEqual(len(list_prop), 2)
+                self.assertTrue(
+                    all(addr[0] in ('^', '@') for addr in list_prop))
+                self.assertIn('@list@example.com', list_prop)
+            else:
+                self.assertEqual(len(list_prop), 1)
+                self.assertTrue(
+                    all(addr.startswith('^') for addr in list_prop))
 
     def test_nonmember_following_member(self):
         self._pckdict['hold_these_nonmembers'] = [
